@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.9 2007/12/29 09:15:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.10 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -46,9 +46,9 @@ require_once SYL_INCLUDE_DIR . '/lib/DB/Dao/SyL_DBDaoTable.php';
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.9 2007/12/29 09:15:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.10 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperation
@@ -60,13 +60,6 @@ class SyL_AdmOperation
      * @var object
      */
     var $form = null;
-    /**
-     * DB֥
-     *
-     * @access private
-     * @var object
-     */
-    var $conn = null;
     /**
      * DAO֥
      *
@@ -107,7 +100,6 @@ class SyL_AdmOperation
     function SyL_AdmOperation(&$form, &$conn, $keys=array())
     {
         $this->form     =& $form;
-        $this->conn     =& $conn;
         $this->dao      =& new SyL_DBDao($conn);
         $this->relation = $this->dao->createRelation();
         foreach ($keys as $key) {
