@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataWeb.php,v 1.5 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataWeb.php,v 1.6 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,9 @@
  * 
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataWeb.php,v 1.5 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataWeb.php,v 1.6 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataWeb extends SyL_Data
@@ -53,11 +53,11 @@ class SyL_DataWeb extends SyL_Data
     var $input_get_array = false;
 
     /**
-     * 󥹥ȥ饯
-     *
+     * ϥѥ᡼򥻥å
+     * 
      * @access public
      */
-    function SyL_DataWeb()
+    function initInputs()
     {
         // ѥ᡼
         $this->setInputs(($_SERVER['REQUEST_METHOD'] == 'POST') ? $_POST + $_GET : $_GET + $_POST);
@@ -71,6 +71,19 @@ class SyL_DataWeb extends SyL_Data
         }
     }
 
+    /**
+     * ǸŪ˥ѥ᡼᥽å
+     * 
+     * @access public
+     * @return array ѥ᡼
+     */
+    function finalOutputs()
+    {
+        $parameters = $this->gets();
+        $this->deletes();
+        return $parameters;
+    }
+
     /**
      * ץѥƥ
      * 
