@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.28 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.29 2008/01/20 15:09:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.28 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.29 2008/01/20 15:09:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -411,19 +411,40 @@ SyL Framework ver. {$version} on PHP {$version_php}
 {$uname}
 EOF;
             // 
+            SyL_Loggers::info("Error mail Type: "    . SYL_MAIL_TYPE);
             SyL_Loggers::info("Error mail Subject: " . $error_mail_subject);
-            SyL_Loggers::info("Error mail To: " .      SYL_MAIL_ADMIN_ADDRESS);
-            SyL_Loggers::info("Error mail body\n" .    $error_mail_body);
+            SyL_Loggers::info("Error mail To: "      . SYL_MAIL_ADMIN_ADDRESS);
+            SyL_Loggers::info("Error mail body\n"    . $error_mail_body);
+
+            $types = explode(':', SYL_MAIL_TYPE);
 
             // 顼᡼¹
             include_once SYL_INCLUDE_DIR . '/lib/SyL_Mail.php';
-            $mail =& SyL_Mail::factory(SYL_MAIL_TYPE);
-            $mail->setSubject($error_mail_subject);
-            $mail->setFrom(SYL_MAIL_ADMIN_ADDRESS);
-            $mail->addTo(SYL_MAIL_ADMIN_ADDRESS);
-            $mail->setBody($error_mail_body);
-            if (!$mail->send()) {
-                SyL_Loggers::error("Error mail send error\n" . $mail->getErrorMessage());
+            $mail =& SyL_Mail::factorySend($types[0]);
+            switch (strtolower($types[0])) {
+            case 'sendmail':
+                if (isset($types[1])) {
+                    $mail->setSendmailPath($types[1]);
+                }
+                break;
+            case 'smtp':
+                if (isset($types[1])) {
+                    $mail->setHost($types[1]);
+                } else {
+                    SyL_Loggers::warn("Mail host not found");
+                }
+                if (isset($types[2])) {
+                    $mail->setPort($types[2]);
+                }
+                break;
+            }
+            $message =& $mail->createMessage();
+            $message->setSubject($error_mail_subject);
+            $message->setFrom(SYL_MAIL_ADMIN_ADDRESS);
+            $message->addTo(SYL_MAIL_ADMIN_ADDRESS);
+            $message->setBody($error_mail_body);
+            if (!$mail->send($message)) {
+                SyL_Loggers::error($mail->getErrorMessage());
             }
         }
     }
