@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.18 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.19 2008/01/20 15:09:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.18 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.19 2008/01/20 15:09:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
@@ -142,6 +142,10 @@ class SyL_Router
         include_once SYL_INCLUDE_DIR . "/framework/Router/{$classname}.php";
         $router =& new $classname();
         $router->createActionInfo($data);
+        // եѥå
+        if (!$router->validAction()) {
+            SyL_Response::forward404();
+        }
         $router->changeRoutingConfig($controller);
         return $router;
     }
@@ -264,6 +268,23 @@ class SyL_Router
         }
     }
 
+    /**
+     * եΥѥå
+     * ǥ쥯ȥ꡿եƬ_פϥԲ
+     *
+     * @access public
+     * @return bool true: ͭfalse: ̵
+     */
+    function validAction()
+    {
+        foreach (explode('/', $this->action_file) as $tmp) {
+            if (substr($tmp, 0, 1) == '_') {
+                return false;
+            }
+        }
+        return true;
+    }
+
     /**
      * 󥯥饹̾
      *
